#
# spec file for package python-pytest-httpserver
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pytest-httpserver
Version:        1.1.0
Release:        1.2
Summary:        A HTTP server for pytest
License:        MIT
Group:          Development/Languages/Python
URL:            https://www.github.com/csernazs/pytest-httpserver
Source:         https://files.pythonhosted.org/packages/source/p/pytest_httpserver/pytest_httpserver-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module toml >= 0.10}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Werkzeug >= 2
Requires:       python-pytest
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Werkzeug >= 2}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
# /SECTION
%python_subpackages

%description
This library is for testing HTTP clients without contacting the real
HTTP server. In other words, it is a fake HTTP server which is
accessible via localhost can be started with the pre-defined expected
HTTP requests and their responses.

%prep
%setup -q -n pytest_httpserver-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/pytest_httpserver
%{python_sitelib}/pytest_httpserver-%{version}*-info

%changelog
* Sun Aug 18 2024 Dirk Müller <dmueller@suse.com>
- update to 1.1.0:
  * Fixed an issue related to the leak of httpserver state
    between the tests when httpserver is destructed before the
    other fixtures. #352
  * Fix pytest-httpserver's own tests related to log querying. No
    functional changes in pytest-httpserver code itself. #345
  * New methods added to query for matching requests in the log.
  * Threading support to serve requests in parallel
* Fri Mar  1 2024 Dirk Müller <dmueller@suse.com>
- update to 1.0.10:
  * When there's no handler for the request, add more details to
    the response sent by the server about the request to help
    debugging.
  * Use ruff for linting. It includes some source code changes
    which should not introduce functional changes, or API
    changes.
  * Add __repr__ to RequestHandler object so when it is compared
    (eg. with the log attribute of the server) it will show the
    matcher parameters.
* Wed May 31 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.8:
  * Bug Fixes
* Mon May 22 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.7:
  * With werkzeug 2.3.x the headers type has been updated to not
    allow integers as header values. This restriction followed up
    in pytest-httpserver.
  * Python versions earlier than 3.8 have been deprecated in
    order to support the latest werkzeug.
  * Type hinting for header_value_matcher has been fixed. From
    now, specifying a callable as ``Callable[[str,
    Optional[str], str], bool]`` will be accepted also.
    Providing a ``HeaderValueMatcher`` object will be also
    accepted as before, as it provides the same callable signature
  * Fix Werkzeug deprecation warning about
    ``parse_authorization_header`` call.
  * Replace ``parse_authorization_header`` with
    ``Authorization.from_header`` as suggested. This fix should
    not introduce any functional change for the users.
  * Fix Werkzeug deprecation warning about
    ``werkzeug.urls.url_decode`` call. This call has been changed
    to ``urllib.parse.parse_qsl`` in the implementation.
    This fix should not introduce any functional change for the
    users.
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.6:
  * Add a new way of running tests with the blocking mode. In
    this mode, the http server is synchronized to the main thread
    and the client code is run in a separate thread.
  * Python version classifier updated in pyproject.toml (which
    updates pypi also)
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Thu Aug 18 2022 Ben Greiner <code@bnavigator.de>
- Clean specfile: remove code coverage checker
* Mon Aug 15 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.0.5
  * Packaging of sdist and the wheel fixed by adding the extra
    files only to the sdist and not to the wheel.
- Release 1.0.4
  * Fixed type hinting of HeaderValueMatcher.DEFAULT_MATCHERS,
    which did not allow modifications, however it is explicitly
    allowed in the documentation.
  * Version of flake8 library updated to require 4.0.0+ at minimum.
    This is required to make flake8 working on recent python
    versions.
- Release 1.0.3
  * Additional type hints improvements to make the library more
    mypy compliant. Imports in __init__.py have been updated to
    indicate that this is a namespace package.
  * Package deployment and CI has been migrated to poetry.
    poetry.lock will be kept up to date. Make target "quick-test"
    renamed to "test". Also, minor adjustments were made regarding
    documentation generation. Make targets should be identical.
    Build results like sdist, and wheel are almost identical to the
    one which was made by setuptools.
* Fri Dec 17 2021 pgajdos@suse.com
- pytest-runner is not required for build
* Wed Dec  8 2021 pgajdos@suse.com
- version update to 1.0.2
  * *Breaking change**: The scope of ``httpserver_listen_address`` fixture changed from **function**
  to **session**. This is a requirement to implement the other features listed
  in this release. See the `upgrade guide
  <https://pytest-httpserver.readthedocs.io/en/latest/upgrade.html>`_ for the
  details.
  * many other changes, see CHANGES.rst
* Thu Aug 29 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to 0.3.4
  * renew certs expiring 2019-09-03
* Mon Aug 26 2019 Jan Engelhardt <jengelh@inai.de>
- Use slightly more detailed description.
* Thu Aug  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.3:
  * Besides bytes and string, dict and MultiDict objects can be specified as query_string
  * Add more files to source distribution (sdist). It now contains tests, assets, examples and other files
* Fri Jul 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.1:
  * various bugfixes
  * various documentation updates
* Tue Jul 23 2019 Todd R <toddrme2178@gmail.com>
- Initial version
